@@ -15,7 +15,7 @@
 #' @param output (optional) file path of the output file
 #' @param convert string: format of required output document (besides Pandoc's markdown). Pandoc is called if set via \code{Pandoc.convert} and the converted document could be also opened automatically (see below).
 #' @param open try to open converted document with operating system's default program
-#' @param graph.name character string (default to \code{\%t} when \code{output} is set to \code{stdout} and \code{paste0(basename(output), '-\%n')} otherwise) passed to \code{\link{evals}}.  Besides \code{\link{evals}}'s possible tags \code{\%i} is also available which would be replaced by the chunk number and \code{\%I} with the order of the current expression.
+#' @param graph.name character string (default to \code{\%t} when \code{output} is set to \code{stdout} and \code{paste0(basename(output), '-\%n')} otherwise) passed to \code{\link{evals}}.  Besides \code{\link{evals}}'s possible tags \code{\%i} is also available which would be replaced by the chunk number (and optionally an integer which would handle nested \code{brew} calls) and \code{\%I} with the order of the current expression.
 #' @param graph.dir character string (default to \code{tempdir()} when \code{output} is set to \code{stdout} and \code{dirname(graph.name)} otherwise) passed to \code{\link{evals}}
 #' @param graph.hi.res render high resolution images of plots? Default is \code{FALSE} except for HTML output.
 #' @param text character vector (treated as the content of the \code{file}
@@ -79,8 +79,10 @@ Pandoc.brew <- function(file = stdin(), output = stdout(), convert = FALSE, open
         text <- paste(readLines(file, warn = FALSE), collapse = '\n')
 
     ## id of chunk
-    assign('chunkID', 0, envir = debug)
     assign('cmdID', 0, envir = debug)
+    assign('chunkID', 0, envir = debug)
+    assign('nested', debug$nested + 1, envir = debug)
+    assign('nestedID', debug$nestedID + 1, envir = debug)
 
     ## helper fn
     showCode <- function(..., envir = parent.frame(), cache = evalsOptions('cache')) {
@@ -143,6 +145,9 @@ Pandoc.brew <- function(file = stdin(), output = stdout(), convert = FALSE, open
     ## there is no sense of chunkID outside of brew
     assign('chunkID', NULL, envir = debug)
     assign('cmdID', NULL, envir = debug)
+    assign('nested', debug$nested - 1, envir = debug)
+    if (debug$nested == 0)
+        assign('nestedID', 0, envir = debug)
 
     invisible(get('.storage', envir = envir))
 
