@@ -206,7 +206,7 @@ eval.msgs <- function(src, env = NULL, showInvisible = FALSE, graph.unify = eval
                         rv$theme$panel.border     <- ggplot2::element_rect(fill = NA, colour = tc)
                         rv$theme$panel.background <- ggplot2::element_rect(fill = pc, colour = tc)
                     } else {
-                        rv$theme$legend.key       <- rv$theme$strip.background <- ggplot2::element_rect(col = gc, fill = 'transparent')
+                        rv$theme$legend.key       <- rv$theme$strip.background <- ggplot2::element_rect(colour = gc, fill = 'transparent')
                         rv$theme$panel.border     <- ggplot2::element_rect(fill = NA, colour = gc)
                         rv$theme$panel.background <- ggplot2::element_rect(fill = pc, colour = gc)
                     }
@@ -684,9 +684,13 @@ evals <- function(txt, parse = TRUE, cache = TRUE, cache.mode = c('environment',
         file.name <- gsub('%d', `%d`, graph.name, fixed = TRUE)
 
         ## chunk ID
-        if (!is.null(debug$chunkID))
-            file.name <- gsub('%i', debug$chunkID, file.name, fixed = TRUE)
-        if (!is.null(debug$cmdID)) {
+        if (length(debug$chunkID) > 0) {
+            if ((length(debug$nestedID) > 0) && (debug$nestedID > 1))
+                file.name <- gsub('%i', paste0(debug$nestedID, '_', debug$chunkID), file.name, fixed = TRUE)
+            else
+                file.name <- gsub('%i', debug$chunkID, file.name, fixed = TRUE)
+        }
+        if (length(debug$cmdID) > 0) {
             assign('cmdID', debug$cmdID + 1, envir = debug)
             file.name <- gsub('%I', debug$cmdID, file.name, fixed = TRUE)
         }
@@ -708,9 +712,9 @@ evals <- function(txt, parse = TRUE, cache = TRUE, cache.mode = c('environment',
         if (grepl('%n', file.name)) {
             if (length(strsplit(sprintf('placeholder%splaceholder', file.name), '%n')[[1]]) > 2)
                 stop('File name contains more then 1 "%n"!')
-            similar.files <- list.files(graph.dir, pattern = sprintf('^%s\\.(jpeg|tiff|png|svg|bmp)$', gsub('%t', '[a-z0-9]*', gsub('%d|%n|%i', '[[:digit:]]*', basename(file.name)))))
+            similar.files <- list.files(graph.dir, pattern = sprintf('^%s\\.(jpeg|tiff|png|svg|bmp|pdf)$', gsub('%t', '[a-z0-9]*', gsub('%d|%n|%i', '[[:digit:]]*', basename(file.name)))))
             if (length(similar.files) > 0) {
-                similar.files <- sub('\\.(jpeg|tiff|png|svg|bmp)$', '', similar.files)
+                similar.files <- sub('\\.(jpeg|tiff|png|svg|bmp|pdf)$', '', similar.files)
                 rep <- gsub('%t', '[a-z0-9]*', gsub('%d|%i', '[[:digit:]]*', strsplit(basename(file.name), '%n')[[1]]))
                 `%n` <- max(as.numeric(gsub(paste(rep, collapse = '|'), '', similar.files))) + 1
             } else
@@ -884,14 +888,21 @@ evals <- function(txt, parse = TRUE, cache = TRUE, cache.mode = c('environment',
         ## close grDevice
         clear.devs()
 
+        ## check if image file was created
+        if (is.character(graph))
+            if (!file.exists(file))
+                res$msg$errors <- c(res$msg$errors, paste('Image file not written by:', paste(src, collapse = ';')))
+
         ## error handling
         if (!is.null(res$msg$errors)) {
 
             ## removing injected base::plot fns
             if (graph.unify)
-                rm(list = c('plot', 'barplot', 'lines', 'pie', 'boxplot', 'polygon', 'points','legend', 'hist', 'pairs', 'stripchart'), envir = env)
+                rm(list = ls(envir = masked.plots), envir = env)
 
             class(res) <- 'evals'
+            if ('plot.new has not been called yet' %in% res$msg$errors)
+                res$msg$errors <- 'plot.new has not been called yet - Please note that all R commands are parsed and evaluated separately. To override this default behavior, add a plus sign (+) as the first character of the line(s) to evaluate with the prior one(s).'
             return(res)
         }
 
